﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;
using ID696116.Resources;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace ID696116
{
    public partial class MainPage : PhoneApplicationPage
    {
        // Constructor
        public MainPage()
        {
            InitializeComponent();
            this.DataContext = ViewModel.GetInstance();
            ViewModel.GetInstance().SelectionChanged += MainPage_SelectionChanged;
        }

        void MainPage_SelectionChanged(object sender, EventArgs e)
        {
            NavigationService.Navigate(new Uri("/Page2.xaml", UriKind.RelativeOrAbsolute));
        }
    }


    public class MyDataItem
    {
        public MyDataItem(string title, string imageSource)
        {
            this.Title = title;
            this.ImageSource = new Uri(imageSource, UriKind.RelativeOrAbsolute);
        }
        public string Title { get; set; }
        public Uri ImageSource { get; set; }
    }

    public class ViewModel : INotifyPropertyChanged
    {
        private MyDataItem selectedItem;
        private ObservableCollection<MyDataItem> itemsSource;

        public event EventHandler SelectionChanged;

        public ViewModel()
        {
            this.itemsSource = new ObservableCollection<MyDataItem>();
            this.itemsSource.Add(new MyDataItem("Sample 0", "/Images/sample_0.jpg"));
            this.itemsSource.Add(new MyDataItem("Sample 1", "/Images/sample_1.jpg"));
            this.itemsSource.Add(new MyDataItem("Sample 2", "/Images/sample_2.jpg"));
            this.itemsSource.Add(new MyDataItem("Sample 3", "/Images/sample_3.jpg"));
            this.itemsSource.Add(new MyDataItem("Sample 4", "/Images/sample_4.jpg"));
            this.itemsSource.Add(new MyDataItem("Sample 5", "/Images/sample_5.jpg"));
            this.itemsSource.Add(new MyDataItem("Sample 6", "/Images/sample_6.jpg"));
            this.itemsSource.Add(new MyDataItem("Sample 7", "/Images/sample_7.jpg"));
        }

        public MyDataItem SelectedItem
        {
            get
            {
                return this.selectedItem;
            }
            set
            {
                if (this.selectedItem != value)
                {
                    this.selectedItem = value;
                    this.RaiseSelectionChanged();
                    this.OnPropertyChanged("SelectedItem");
                }
            }
        }

        public ObservableCollection<MyDataItem> ItemsSource
        {
            get
            {
                return this.itemsSource;
            }
            set
            {
                if (this.itemsSource != value)
                {
                    this.itemsSource = value;
                    this.OnPropertyChanged("ItemsSource");
                }
            }
        }

        protected void RaiseSelectionChanged()
        {
            if (this.SelectionChanged != null)
            {
                this.SelectionChanged(this, EventArgs.Empty);
            }
        }

        private static ViewModel instance;

        public static ViewModel GetInstance()
        {
            if (instance == null)
                instance = new ViewModel();

            return instance;
        }

        protected void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
    }
}